============
LyricsMaster
============


.. image:: https://img.shields.io/pypi/v/lyricsmaster.svg
        :target: https://pypi.python.org/pypi/lyricsmaster
        :alt: PyPi Status

.. image:: https://img.shields.io/travis/SekouD/lyricsmaster.svg
        :target: https://travis-ci.org/SekouD/lyricsmaster
        :alt: Linux Continuous Integration Status

.. image:: https://ci.appveyor.com/api/projects/status/73bd1ct4revmlk42/branch/master?svg=true
        :target: https://ci.appveyor.com/project/SekouD/lyricsmaster
        :alt: Windows Continuous Integration Status

.. image:: https://readthedocs.org/projects/lyricsmaster/badge/?version=latest
        :target: https://lyricsmaster.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/SekouD/lyricsmaster/shield.svg
        :target: https://pyup.io/repos/github/SekouD/lyricsmaster/
        :alt: Dependencies Update Status

.. image:: https://codecov.io/gh/SekouD/lyricsmaster/branch/master/graph/badge.svg
        :target: https://codecov.io/gh/SekouD/lyricsmaster
        :alt: Coverage Status

LyricsMaster is a library for downloading lyrics from multiple lyrics providers.

The following Lyrics Providers are supported:

- Lyric Wikia
- AzLyrics
- Genius
- Lyrics007
- MusixMatch
- The Original Hip-Hop (Rap) Lyrics Archive - OHHLA.com
- and more to come soon.


* Free software: MIT license
* Documentation: https://lyricsmaster.readthedocs.io.


Features
--------

- Download Lyrics from LyricWiki, AzLyrics, Genius, Lyrics007, MusixMatch, OHHLA and more.
- Download Lyrics Asynchronously.
- Can make requests over Tor for anonymous downloading of songs.
- Easily save the lyrics on your computer.
